local L = LibStub("AceLocale-3.0"):GetLocale("NeedjaTrackerPlus", true)

function NTP:GetProfileValue(key)
    return self.db.profile[key]
end

function NTP:SetProfileValue(key, value)
    self.db.profile[key] = value
end

function NTP:GetCharValue(key)
    return self.db.char[key]
end

function NTP:SetCharValue(key, value)
    self.db.char[key] = value
end

function NTP:Options()
    if not self.options then
        self.options = {
            type = "group",
            args = {
                general = {
                    type = "group",
                    args = {
                        enable = {
                            type = "toggle",
                            name = L.cfg_enable,
                            order = 1,
                            width = "full",
                            get = function()
                                return self:GetProfileValue('enable')
                            end,
                            set = function(_, value)
                                self:SetProfileValue('enable', value)
                                if value then
                                  -- enable
                                else
                                  -- disable
                                end
                            end,
                        },
                        chatoptions = {
                            type = "header",
                            name = L.cfg_chatoptions,
                            order = 2,
                        },
                        need_warnings = {
                            type = "group",
                            name = L.cfg_need_warnings,
                            order = 3,
                            inline = true,
                            args = {
                                in_party = {
                                    type = "select",
                                    name = L.cfg_in_party,
                                    order = 1,
                                    values = { L.cfg_never, L.cfg_only_leader, L.cfg_always },
                                    get = function()
                                        return self:GetProfileValue('warn_party')
                                    end,
                                    set = function(_, value)
                                        self:SetProfileValue('warn_party', value)
                                    end,
                                },
                                in_lfg_party = {
                                    type = "select",
                                    name = L.cfg_in_lfg_party,
                                    order = 2,
                                    values = { L.cfg_never, L.cfg_only_leader, L.cfg_always },
                                    get = function()
                                        return self:GetProfileValue('warn_lfg_party')
                                    end,
                                    set = function(_, value)
                                        self:SetProfileValue('warn_lfg_party', value)
                                    end,
                                },
                                in_raid = {
                                    type = "select",
                                    name = L.cfg_in_raid,
                                    order = 3,
                                    values = { L.cfg_never, L.cfg_only_leader, L.cfg_leader_and_assist, L.cfg_always },
                                    get = function()
                                        return self:GetProfileValue('warn_raid')
                                    end,
                                    set = function(_, value)
                                        self:SetProfileValue('warn_raid', value)
                                    end,
                                },
                                in_lfr_raid = {
                                    type = "select",
                                    name = L.cfg_in_lgr_raid,
                                    order = 4,
                                    values = { L.cfg_never, L.cfg_only_leader, L.cfg_leader_and_assist, L.cfg_always },
                                    get = function()
                                        return self:GetProfileValue('warn_lfr_raid')
                                    end,
                                    set = function(_, value)
                                        self:SetProfileValue('warn_lfr_raid', value)
                                    end,
                                },
                            }
                        },
                    }
                },
            }
        }
        self.options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db)
    end
    return self.options
end

function NTP:Defaults()
    if not self._defaults then
        self._defaults = {
            profile = {
                enable = true,

                warn_party = 1,
                warn_lfr_party = 1,
                warn_raid = 1,
                warn_lfr_raid = 1,
            },
        }
    end
    return self._defaults
end
